double dsqr(double x)
{
	return x*x;
}
int isqr(int x)
{
	return x*x;
}

void nrerror(char error_text[])
/* Standard error handler */
{
	fprintf(stderr,"Run-time error...\n");
	fprintf(stderr,"%s\n",error_text);
	fprintf(stderr,"...now exiting to system...\n");
	ch=getc(stdin);
	exit(1);
}
void free_ivector(int *v, int nl, int nh)
/* free an int vector allocated with ivector() */
{
	free((FREE_ARG) (v+nl+nh-nh-NR_END));
}
int *ivector(int nl, int nh)
/* allocate an int vector with subscript range v[nl..nh] */
{
	int *v;

	v=(int *)malloc((size_t) ((nh-nl+1+NR_END)*sizeof(int)));
	if (!v) nrerror("allocation failure in ivector()");
	return v-nl+NR_END;
}
double **matrix(int nrl, int nrh, int ncl, int nch)
/* allocate a double matrix with subscript range m[nrl..nrh][ncl..nch] */
{
	int i, nrow=nrh-nrl+1,ncol=nch-ncl+1;
	double **m;

	/* allocate pointers to rows */
	m=(double **) malloc((size_t)((nrow+NR_END)*sizeof(double*)));
	if (!m) nrerror("allocation failure 1 in matrix()");
	m += NR_END;
	m -= nrl;

	/* allocate rows and set pointers to them */
	m[nrl]=(double *) malloc((size_t)((nrow*ncol+NR_END)*sizeof(double)));
	if (!m[nrl]) nrerror("allocation failure 2 in matrix()");
	m[nrl] += NR_END;
	m[nrl] -= ncl;

	for(i=nrl+1;i<=nrh;i++) m[i]=m[i-1]+ncol;

	/* return pointer to array of pointers to rows */
	return m;
}
int **imatrix(int nrl, int nrh, int ncl, int nch)
/* allocate a int matrix with subscript range m[nrl..nrh][ncl..nch] */
{
	int i, nrow=nrh-nrl+1,ncol=nch-ncl+1;
	int **m;

	/* allocate pointers to rows */
	m=(int **) malloc((size_t)((nrow+NR_END)*sizeof(int*)));
	if (!m) nrerror("allocation failure 1 in matrix()");
	m += NR_END;
	m -= nrl;


	/* allocate rows and set pointers to them */
	m[nrl]=(int *) malloc((size_t)((nrow*ncol+NR_END)*sizeof(int)));
	if (!m[nrl]) nrerror("allocation failure 2 in matrix()");
	m[nrl] += NR_END;
	m[nrl] -= ncl;

	for(i=nrl+1;i<=nrh;i++) m[i]=m[i-1]+ncol;

	/* return pointer to array of pointers to rows */
	return m;
}
void free_imatrix(int **m, int nrl, int nrh, int ncl, int nch)
/* free an int matrix allocated by imatrix() */
{
	free((FREE_ARG) (m[nrl]+ncl-NR_END));
	free((FREE_ARG) (m+nrl-NR_END));
	nrh *=nch; /* To avoid warnings!!!*/
}
double *vector(int nl, int nh)
/* allocate a double vector with subscript range v[nl..nh] */
{
	double *v;

	v=(double *)malloc((size_t) ((nh-nl+1+NR_END)*sizeof(double)));
	if (!v) nrerror("allocation failure in vector()");
	return v-nl+NR_END;
}
double ***f3tensor(int nrl, int nrh, int ncl, int nch, int ndl, int ndh)
/* allocate a double 3tensor with range t[nrl..nrh][ncl..nch][ndl..ndh] */
{
	int i,j,nrow=nrh-nrl+1,ncol=nch-ncl+1,ndep=ndh-ndl+1;
	double ***t;

	/* allocate pointers to pointers to rows */
	t=(double ***) malloc((size_t)((nrow+NR_END)*sizeof(double**)));
	if (!t) nrerror("allocation failure 1 in f3tensor()");
	t += NR_END;
	t -= nrl;

	/* allocate pointers to rows and set pointers to them */
	t[nrl]=(double **) malloc((size_t)((nrow*ncol+NR_END)*sizeof(double*)));
	if (!t[nrl]) nrerror("allocation failure 2 in f3tensor()");
	t[nrl] += NR_END;
	t[nrl] -= ncl;

	/* allocate rows and set pointers to them */
	t[nrl][ncl]=(double *) malloc((size_t)((nrow*ncol*ndep+NR_END)*sizeof(double)));
	if (!t[nrl][ncl]) nrerror("allocation failure 3 in f3tensor()");
	t[nrl][ncl] += NR_END;
	t[nrl][ncl] -= ndl;

	for(j=ncl+1;j<=nch;j++) t[nrl][j]=t[nrl][j-1]+ndep;
	for(i=nrl+1;i<=nrh;i++) {
		t[i]=t[i-1]+ncol;
		t[i][ncl]=t[i-1][ncl]+ncol*ndep;
		for(j=ncl+1;j<=nch;j++) t[i][j]=t[i][j-1]+ndep;
	}

	/* return pointer to array of pointers to rows */
	return t;
}
void free_vector(double *v, int nl, int nh)
/* free a double vector allocated with vector() */
{
	free((FREE_ARG) (v+nl+nh-nh-NR_END));
}
void free_matrix(double **m, int nrl, int nrh, int ncl, int nch)
/* free a double matrix allocated by matrix() */
{
	free((FREE_ARG) (m[nrl]+ncl+nrh-nrh-NR_END));
	free((FREE_ARG) (m+nrl+nch-nch-NR_END));
}
void free_f3tensor(double ***t, int nrl, int nrh, int ncl, int nch,
	int ndl, int ndh)
/* free a double f3tensor allocated by f3tensor() */
{
	free((FREE_ARG) (t[nrl][ncl]+ndl+ndh-ndh-NR_END));
	free((FREE_ARG) (t[nrl]+ncl+nch-nch-NR_END));
	free((FREE_ARG) (t+nrl+nrh-nrh-NR_END));
}

void lubksb(double **a, int n, int *indx, double *b)
{
	int i,ii=0,ip,j;
	double sum;

	for (i=1;i<=n;i++) {
		ip=indx[i];
		sum=b[ip];
		b[ip]=b[i];
		if (ii)
			for (j=ii;j<=i-1;j++) sum -= a[i][j]*b[j];
		else if (sum) ii=i;
		b[i]=sum;
	}
	for (i=n;i>=1;i--) {
		sum=b[i];
		for (j=i+1;j<=n;j++) sum -= a[i][j]*b[j];
		b[i]=sum/a[i][i];
	}
}
void ludcmp(double **a, int n, int *indx, double *d)
{
	int i,imax,j,k;
	double big,dum,sum,temp;
	double *vv;

	vv=vector(1,n);
	*d=1.0;
	for (i=1;i<=n;i++) {
		big=0.0;
		for (j=1;j<=n;j++)
			if ((temp=fabs(a[i][j])) > big) big=temp;
		if (big == 0.0) nrerror("Singular matrix in routine ludcmp");
		vv[i]=1.0/big;
	}
	for (j=1;j<=n;j++) {
		for (i=1;i<j;i++) {
			sum=a[i][j];
			for (k=1;k<i;k++) sum -= a[i][k]*a[k][j];
			a[i][j]=sum;
		}
		big=0.0;
		for (i=j;i<=n;i++) {
			sum=a[i][j];
			for (k=1;k<j;k++)
				sum -= a[i][k]*a[k][j];
			a[i][j]=sum;
			if ( (dum=vv[i]*fabs(sum)) >= big) {
				big=dum;
				imax=i;
			}
		}
		if (j != imax) {
			for (k=1;k<=n;k++) {
				dum=a[imax][k];
				a[imax][k]=a[j][k];
				a[j][k]=dum;
			}
			*d = -(*d);
			vv[imax]=vv[j];
		}
		indx[j]=imax;
		if (a[j][j] == 0.0) a[j][j]=TINY;
		if (j != n) {
			dum=1.0/(a[j][j]);
			for (i=j+1;i<=n;i++) a[i][j] *= dum;
		}
	}
	free_vector(vv,1,n);
}
void calc_A_c(void)
{
	int i,j,k;
/* A_c = (1/(L_star + L_c))*(L_star + L_old)*/
	for(i=1;i<=6;i++)
		for(j=1;j<=6;j++)
			*(*(G+i)+j) = *(*(L_star+i)+j) + *(*(L_c+i)+j);
	ludcmp(G,6,indx,&d);
	for(j=1;j<=6;j++)
	{
		for(i=1;i<=6;i++)
			*(col+i)=0.0;
		*(col+j)=1.0;
		lubksb(G,6,indx,col);
		for(i=1;i<=6;i++)
			*(*(invG+i)+j) = *(col+i);
	}
	for(i=1;i<=6;i++)
		for(j=1;j<=6;j++)
			*(*(G+i)+j) =  *(*(L_star+i)+j) + *(*(L_old+i)+j);
	for(i=1;i<=6;i++)
		for(j=1;j<=6;j++)
		{
			*(*(A_c+i)+j)=0;
			for(k=1;k<=6;k++)
				*(*(A_c+i)+j) += *(*(invG+i)+k) * *(*(G+k)+j);
		}
}/*void calc_A_c(void)*/

void calc_L_c(void)
{
	double **X,**Y,max;
	int b,t,i,j;
	X=matrix(1,max_sys,1,max_sys);
	Y=matrix(1,max_sys,1,max_sys);
	for(b=1;b<=max_sys;b++)
		for(t=1;t<=max_sys;t++)
		{
			*(*(X+b)+t) = *(*(h+(*(activ_sys+b)))+(*(activ_sys+t)));
			for(i=1;i<=6;i++)
			{
				*(vec6+i)=0;
				for(j=1;j<=6;j++)
					*(vec6+i) += *(*(l_c+i)+j) * *(*(mu_vec+(*(activ_sys+t)))+j);
				*(*(X+b)+t) += *(*(mu_vec+(*(activ_sys+b)))+i) * *(vec6+i);
			}
		}
	ludcmp(X,max_sys,indx,&d);
	sing=0;max=0;
	for(b=1;b<=max_sys;b++)
		if(fabs(*(*(X+b)+b)) > max)
			max=fabs(*(*(X+b)+b));
	for(b=1;b<=max_sys;b++)
		if(fabs(*(*(X+b)+b)) < 1e-6*max)
			sing=1;

if(sing==0)
{
	for(j=1;j<=max_sys;j++)
	{
		for(i=1;i<=max_sys;i++)
			*(col+i)=0.0;
		*(col+j)=1.0;
		lubksb(X,max_sys,indx,col);
		for(i=1;i<=max_sys;i++)
			*(*(Y+i)+j)= *(col+i);
	}
/*beregning af f-vaerdier!*/
	for(b=1;b<=max_sys;b++)
		for(i=1;i<=6;i++)
		{
			*(*(f+b)+i) = 0;
			for(t=1;t<=max_sys;t++)
				for(j=1;j<=6;j++)
						*(*(f+b)+i) += *(*(l_c+i)+j) * *(*(mu_vec+(*(activ_sys+t)))+j) * *(*(Y+b)+t);
		}
	for(i=1;i<=6;i++)
		for(j=1;j<=6;j++)
		{
			*(*(G+i)+j) = 0;
			for(b=1;b<=max_sys;b++)
				*(*(G+i)+j) += *(*(mu_vec+(*(activ_sys+b)))+i) * *(*(f+b)+j);
		}
	for(i=1;i<=6;i++)
		for(j=1;j<=6;j++)
		{
			if(i==j)
				*(*(invG+i)+j) = 1.0 - *(*(G+i)+j);
			else
				*(*(invG+i)+j) = 0.0 - *(*(G+i)+j);
		}
	for(i=1;i<=6;i++)
		for(j=1;j<=6;j++)
		{
			*(*(L_c+i)+j)=0;
			for(k=1;k<=6;k++)
				*(*(L_c+i)+j) += *(*(l_c+i)+k) * *(*(invG+k)+j);
		}
}/* if(sing==0) */
	free_matrix(X,1,max_sys,1,max_sys);
	free_matrix(Y,1,max_sys,1,max_sys);
}/*void calc_L_c(void)*/

double kneer(double x, double y)
{
	int i,j,k,l,m,n;
	*(K+1)=sin(x)*cos(y);
	*(K+2)=sin(x)*sin(y);
	*(K+3)=cos(x);
	for(i=1;i<=3;i++)
		for(k=1;k<=3;k++)
		{
			*(*(M+i)+k)=0;
			for(j=1;j<=3;j++)
				for(l=1;l<=3;l++)
				{
						  if(i==1 && j==1) m=1;
					else if(i==2 && j==2) m=2;
					else if(i==3 && j==3) m=3;
					else if(i==2 && j==3) m=4;
					else if(i==3 && j==1) m=5;
					else if(i==1 && j==2) m=6;
					else if(i==3 && j==2) m=4;
					else if(i==1 && j==3) m=5;
					else m=6;
						  if(k==1 && l==1) n=1;
					else if(k==2 && l==2) n=2;
					else if(k==3 && l==3) n=3;
					else if(k==2 && l==3) n=4;
					else if(k==3 && l==1) n=5;
					else if(k==1 && l==2) n=6;
					else if(k==3 && l==2) n=4;
					else if(k==1 && l==3) n=5;
					else n=6;
					*(*(M+i)+k) +=  *(*(L_old+m)+n) * *(K+j) * *(K+l);
				}
		}
	ludcmp(M,3,indx,&d);
	for(j=1;j<=3;j++)
	{
		for(i=1;i<=3;i++)
			*(col+i)=0.0;
		*(col+j)=1.0;
		lubksb(M,3,indx,col);
		for(i=1;i<=3;i++)
			*(*(U+i)+j)= *(col+i);
	}
	return (*(*(U+r)+t) * *(K+u) * *(K+s) +
			  *(*(U+s)+t) * *(K+u) * *(K+r) +
			  *(*(U+r)+u) * *(K+t) * *(K+s) +
			  *(*(U+s)+u) * *(K+t) * *(K+r))* sin(x);
}
double qgaus(double (*func)(double), double a, double b)
{
	int j;
	double xr,xm,dx,s;
	double x[]={0.0,0.1080549487073436680,0.3191123689278897450,
						 0.5152486363581541000,0.6872929048116854790,
						 0.8272013150697650200,0.9284348836635735180,
						 0.9862838086968123140};
	double w[]={0.0,0.2152638534631578230,0.2051984637212955760,
						 0.1855383974779363510,0.1572031671581481100,
						 0.1215185706867094590,0.0801580871073769019,
						 0.0351194603317491055};
	xm=0.5*(b+a);
	xr=0.5*(b-a);
	s=0;
	for (j=1;j<=7;j++)
	{
		dx=xr*x[j];
		s += w[j]*((*func)(xm+dx)+(*func)(xm-dx));
	}
	return s *= xr;
}
double yy1(double x)
{
	x*=1;
	return 0;
}
double yy2(double x)
{
	x*=1;
	return 2*M_PI;
}
double quad2d(double (*func)(double, double), double x1, double x2)
{
	double qgaus(double (*func)(double), double a, double b);
	double f1(double x);

	nrfunc=func;
	return qgaus(f1,x1,x2);
}
double f1(double x)
{
	double qgaus(double (*func)(double), double a, double b);
	double f2(double y);
	double yy1(double),yy2(double);

	xsav=x;
	return qgaus(f2,yy1(x),yy2(x));
}
double f2(double y)
{
	return (*nrfunc)(xsav,y);
}
void lstar(void)
{
	for(i=4;i<=6;i++)
		for(j=4;j<=6;j++)
			*(*(L_old+i)+j) /= 2;
	for(i=4;i<=6;i++)
		for(j=1;j<=3;j++)
			*(*(L_old+i)+j) /= s2;
	for(i=1;i<=3;i++)
		for(j=4;j<=6;j++)
			*(*(L_old+i)+j) /= s2;
	for(i=1;i<=6;i++)
		for(j=1;j<=6;j++)
		{
				  if(i==1) {r=1; s=1;}
			else if(i==2) {r=2; s=2;}
			else if(i==3) {r=3; s=3;}
			else if(i==4) {r=2; s=3;}
			else if(i==5) {r=3; s=1;}
						else {r=1; s=2;}
				  if(j==1) {t=1; u=1;}
			else if(j==2) {t=2; u=2;}
			else if(j==3) {t=3; u=3;}
			else if(j==4) {t=2; u=3;}
			else if(j==5) {t=3; u=1;}
						else {t=1; u=2;}
			*(*(G+i)+j) = quad2d(*kneer,0,M_PI)/(16*M_PI);
		}
	for(i=4;i<=6;i++)
		for(j=4;j<=6;j++)
		{
			*(*(G+i)+j) *= 2;
			*(*(L_old+i)+j) *= 2;
		}
	for(i=4;i<=6;i++)
		for(j=1;j<=3;j++)
		{
			*(*(G+i)+j) *= s2;
			*(*(L_old+i)+j) *= s2;
		}
	for(i=1;i<=3;i++)
		for(j=4;j<=6;j++)
		{
			*(*(G+i)+j) *= s2;
			*(*(L_old+i)+j) *= s2;
		}
	ludcmp(G,6,indx,&d);
	for(j=1;j<=6;j++)
	{
		for(i=1;i<=6;i++)
			*(col+i)=0.0;
		*(col+j)=1.0;
		lubksb(G,6,indx,col);
		for(i=1;i<=6;i++)
			*(*(invG+i)+j)= *(col+i);
	}
	for(i=1;i<=6;i++)
		for(j=1;j<=6;j++)
			*(*(L_star+i)+j) = *(*(invG+i)+j) - *(*(L_old+i)+j);
}/*void lstar(void)*/

void check_angle1(int reflex, double ang, int direction)
{
	int sel,i,j,stop;
	double *polevec,*mdir,length,dir1,dir2,dir3,ins1,ins2,ins3;
	polevec=vector(1,3);
	mdir=vector(1,3);
	for(i=1;i<=3;i++)
		*(mdir+i) = 0;
	*(mdir+direction) = 1;
	for(i=1;i<=3;i++)
	{
		*(polevec+i) = 0;
		for(j=1;j<=3;j++)
			*(polevec+i) += *(*(q+j)+i)* *(mdir+j);
	}
	switch(reflex)
	{
		case 1:  ins1 = 1; ins2 = 1; ins3 = 1; break;
		case 2:  ins1 = 2; ins2 = 0; ins3 = 0; break;
		case 3:  ins1 = 2; ins2 = 2; ins3 = 0; break;
		case 4:  ins1 = 3; ins2 = 1; ins3 = 1; break;
		case 5:  ins1 = 3; ins2 = 3; ins3 = 1; break;
		case 6:  ins1 = 4; ins2 = 2; ins3 = 0; break;
		case 7:  ins1 = 4; ins2 = 2; ins3 = 2; break;
		case 8:  ins1 = 5; ins2 = 3; ins3 = 1; break;
		case 9:  ins1 = 6; ins2 = 2; ins3 = 0; break;
		case 10: ins1 = 3; ins2 = 2; ins3 = 1; break;
		default: exit(1);
	}

	length = sqrt(isqr(ins1) + isqr(ins2) + isqr(ins3))*
				sqrt(dsqr(*(polevec+1)) + dsqr(*(polevec+2)) + dsqr(*(polevec+3)));
	sel=0;
	stop=0;
	while(sel<24)
	{
		sel++;
		switch(sel)
		{
			case  1:	dir1 =  ins1;	dir2 =  ins2;	dir3 =  ins3;	break;
			case  2:	dir1 = -ins1;	dir2 =  ins2;	dir3 =  ins3;	break;
			case  3:	dir1 =  ins1;	dir2 = -ins2;	dir3 =  ins3;	break;
			case  4:	dir1 =  ins1;	dir2 =  ins2;	dir3 = -ins3;	break;
			case  5:	dir1 =  ins1;	dir2 =  ins3;	dir3 =  ins2;	break;
			case  6:	dir1 = -ins1;	dir2 =  ins3;	dir3 =  ins2;	break;
			case  7:	dir1 =  ins1;	dir2 = -ins3;	dir3 =  ins2;	break;
			case  8:	dir1 =  ins1;	dir2 =  ins3;	dir3 = -ins2;	break;
			case  9:	dir1 =  ins2;	dir2 =  ins1;	dir3 =  ins3;	break;
			case 10:	dir1 = -ins2;	dir2 =  ins1;	dir3 =  ins3;	break;
			case 11:	dir1 =  ins2;	dir2 = -ins1;	dir3 =  ins3;	break;
			case 12:	dir1 =  ins2;	dir2 =  ins1;	dir3 = -ins3;	break;
			case 13:	dir1 =  ins2;	dir2 =  ins3;	dir3 =  ins1;	break;
			case 14:	dir1 = -ins2;	dir2 =  ins3;	dir3 =  ins1;	break;
			case 15:	dir1 =  ins2;	dir2 = -ins3;	dir3 =  ins1;	break;
			case 16:	dir1 =  ins2;	dir2 =  ins3;	dir3 = -ins1;	break;
			case 17:	dir1 =  ins3;	dir2 =  ins1;	dir3 =  ins2;	break;
			case 18:	dir1 = -ins3;	dir2 =  ins1;	dir3 =  ins2;	break;
			case 19:	dir1 =  ins3;  dir2 = -ins1;	dir3 =  ins2;	break;
			case 20:	dir1 =  ins3;	dir2 =  ins1;	dir3 = -ins2;	break;
			case 21:	dir1 =  ins3;	dir2 =  ins2;	dir3 =  ins1;	break;
			case 22:	dir1 = -ins3;	dir2 =  ins2;	dir3 =  ins1;	break;
			case 23:	dir1 =  ins3;  dir2 = -ins2;	dir3 =  ins1;	break;
			default:	dir1 =  ins3;	dir2 =  ins2;	dir3 = -ins1;
		}
if(length==0)
{
printf("length step=%d grain=%d",step,grain);
getc(stdin);
}
		if(fabs(*(polevec+1)*dir1 + *(polevec+2)*dir2 + *(polevec+3)*dir3)/length >= ang)
		{
			stop=1;
			break;
		}
	}
	if(stop==1)
	{
		if(direction==3)
		{
			for(i=1;i<=6;i++)
			{
				*(*(s_tra+reflex)+i) += *(vec6+i);
				*(*(e_tra+reflex)+i) += *(ep_temp+i);
			}
			*(gr_tra+reflex) += 1;
			*(*(e_stddev3+(*(gr_tra+reflex)))+reflex) = *(ep_temp+3);
			*(M_tra+reflex) += mfactor;
		}
		else if(direction==2)
		{
			for(i=1;i<=6;i++)
			{
				*(*(s_nor+reflex)+i) += *(vec6+i);
				*(*(e_nor+reflex)+i) += *(ep_temp+i);
			}
			*(gr_nor+reflex) += 1;
			*(*(e_stddev2+(*(gr_nor+reflex)))+reflex) = *(ep_temp+2);
			*(M_nor+reflex) += mfactor;
		}
		else
		{
			for(i=1;i<=6;i++)
			{
				*(*(s_dir+reflex)+i) += *(vec6+i);
				*(*(e_dir+reflex)+i) += *(ep_temp+i);
			}
			*(gr_dir+reflex) += 1;
			*(*(e_stddev+(*(gr_dir+reflex)))+reflex) = *(ep_temp+1);
			*(M_dir+reflex) += mfactor;
		}
	}
	free_vector(polevec,1,3);
	free_vector(mdir,1,3);
}/* void check_angle1*/

double step_func(double x)
{
	int i,j;
	*(e_dot+1) = x;
	for(i=2;i<=6;i++)
		*(e_dot+i) = 0;
	for(i=1;i<=6;i++)
		for(j=1;j<=6;j++)
			*(*(L6+i)+j) = *(*(L_old+i)+j);
	ludcmp(L6,6,indx,&d);
	lubksb(L6,6,indx,e_dot);
	return ep_dot - *(e_dot+1);
}

double gamma_func(double x)
{
	int i,j;
	for(i=1;i<=6;i++)
	{
		*(e_c_dot+i) = 0;
		for(j=1;j<=max_sys;j++)
			*(e_c_dot+i) += *(*(mu_vec+(*(activ_sys+j)))+i) * x;
	}
	return ep_dot - *(e_c_dot+1);
}

double rtsec(double (*func)(double), double x1, double x2, double xacc)
{
	void nrerror(char error_text[]);
	int j;
	double fl,f,dx,swap,xl,rts;

	fl=(*func)(x1);
	f=(*func)(x2);
	if (fabs(fl) < fabs(f)) {
		rts=x1;
		xl=x2;
		swap=fl;
		fl=f;
		f=swap;
	} else {
		xl=x1;
		rts=x2;
	}
	for (j=1;j<=MAXIT;j++) {
		dx=(xl-rts)*f/(f-fl);
		xl=rts;
		fl=f;
		rts += dx;
		f=(*func)(rts);
		if (fabs(dx) < xacc || f == 0.0) return rts;
	}
	nrerror("Maximum number of iterations exceeded in rtsec");
	return 0.0;
}



